package com.image.scale;

import java.awt.Desktop;
import java.io.File;
import java.io.IOException;

import java.nio.file.Files;
import java.nio.file.Path;

import com.grapecity.documents.excel.Workbook;
import com.grapecity.documents.excel.IWorksheet;
import com.grapecity.documents.excel.SaveFileFormat;

import com.grapecity.documents.excel.drawing.IShape;
import com.grapecity.documents.excel.drawing.ImageType;

public class App {
  public static void main(String[] args) {
	  try {
		  insertImageToExcel();
		  printShapeDetails();
		  openFile("file.xlsx");
	  }
	  catch(IOException ex) {
		  System.err.println(ex.getMessage());
	  }
  }
  
  private static void insertImageToExcel() throws IOException {
	  Workbook workbook = new Workbook();
	  IWorksheet worksheet1 = workbook.getWorksheets().get(0);
	  worksheet1.setName("test1");
	  worksheet1.getRange(0, 0).setRowHeight(20);
	  worksheet1.getRange(0, 0).setColumnWidth(34.83);
	  worksheet1.getShapes().addPictureInPixel(
	      Files.newInputStream(Path.of("logo.svg")),
	      ImageType.SVG,
	      9,
	      9,
	      138,
	      23
	  );
	  IWorksheet worksheet2 = workbook.getWorksheets().add();
	  worksheet2.setName("test2");
	  worksheet2.getRange(0, 0).setRowHeight(26);
	  worksheet2.getRange(0, 0).setColumnWidth(16.67);
	  worksheet2.getShapes().addPictureInPixel(
	      Files.newInputStream(Path.of("logo.svg")),
	      ImageType.SVG,
	      9,
	      9,
	      138,
	      23
	  );

	  workbook.save("file.xlsx", SaveFileFormat.Xlsx);
  }
  
  private static void printShapeDetails() {
	  Workbook book = new Workbook();
	  book.open("file.xlsx");
	  IWorksheet sheet1 = book.getWorksheets().get("test1");
	  IWorksheet sheet2 = book.getWorksheets().get("test2");
	  
	  IShape s1 = sheet1.getShapes().get(0);
	  IShape s2 = sheet2.getShapes().get(0);
	  
	  System.out.println(">Sheet 1 shape");
	  System.out.println(">>Height in Pixel : " + s1.getHeightInPixel());
	  System.out.println(">>Width in Pixel : " + s1.getWidthInPixel());
	  
	  System.out.println("\n>Sheet 2 shape");
	  System.out.println(">>Height in Pixel : " + s2.getHeightInPixel());
	  System.out.println(">>Width in Pixel : " + s2.getWidthInPixel());
  }
  
  private static void openFile(String filePath) {
	  File file = new File(filePath);
      try {
          if (Desktop.isDesktopSupported()) {
              Desktop desktop = Desktop.getDesktop();
              if (file.exists()) {
                  desktop.open(file);
              } else {
                  System.err.println("File does not exist: " + file.getAbsolutePath());
              }
          } else {
              System.err.println("Desktop is not supported.");
          }
      } catch (IOException e) {
          e.printStackTrace();
          System.err.println("Error opening file: " + e.getMessage());
      }
  }
}